"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Jobs = void 0;
const axios_1 = require("axios");
const auth_1 = require("./util/auth");
const scopes = ['https://www.googleapis.com/auth/cloud-platform'];
const JOBS_API_HOST = "https://us-central1-run.googleapis.com/apis/run.googleapis.com/v1/namespaces/";
async function getAxiosConfig(projectName, serviceAccount) {
    const headers = await (0, auth_1.getAuthHeader)(projectName, serviceAccount, scopes);
    return { headers };
}
class Jobs {
    constructor(projectName, serviceAccount) {
        this.projectName = projectName;
        this.serviceAccount = serviceAccount;
    }
    async isJobRunning(jobId) {
        const config = await getAxiosConfig(this.projectName, this.serviceAccount);
        config.params = {
            page_size: 1,
            labelSelector: `run.googleapis.com/job=${jobId}`
        };
        const axios = new axios_1.Axios({});
        try {
            const response = await axios.get(JOBS_API_HOST + this.projectName + '/executions', config);
            const data = JSON.parse(response.data);
            if (data.items?.length > 0) {
                const runningCount = data.items[0]?.status?.runningCount || 0;
                return runningCount > 0;
            }
            else
                return false;
        }
        catch (e) {
            throw Error(e.message);
        }
    }
    async runJob(jobId) {
        try {
            const config = await getAxiosConfig(this.projectName, this.serviceAccount);
            const axios = new axios_1.Axios({});
            await axios.post(JOBS_API_HOST + this.projectName + '/jobs/' + jobId + ':run', Buffer.from("{}"), config);
            return true;
        }
        catch (e) {
            return false;
        }
    }
    async listJobs() {
        const config = await getAxiosConfig(this.projectName, this.serviceAccount);
        const axios = new axios_1.Axios({});
        const { data } = await axios.get(JOBS_API_HOST + this.projectName + '/jobs', config);
        return data;
    }
    async getJob(jobId) {
        const config = await getAxiosConfig(this.projectName, this.serviceAccount);
        const axios = new axios_1.Axios({});
        const { data } = await axios.get(JOBS_API_HOST + this.projectName + '/jobs/' + jobId, config);
        return data;
    }
}
exports.Jobs = Jobs;
